@@ -137,8 +137,7 @@ class Client(Singleton):
         cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
         cache_data = self.get_cache(cache_key, toObj=False)
         if cache_data is None:
-            # prefix, backend = self._random_pick_backend()
-            prefix, backend = self._get_backend('yao')
+            prefix, backend = self._random_pick_backend()
             
             ret, e = backend.put(path, bucket, bucket_name, tmp)
             if ret:
