@@ -11,12 +11,15 @@ from hamunafs.utils.singleton_wrapper import Singleton
 
 class MQManager(Singleton):
     def __init__(self, host, port, async_mq=False, init=True):
+        if not self.need_init():
+            return
         self.host = host
         self.port = port
         self.async_mq = async_mq
         self.inited = False
         if init:
             self._init()
+        self._inited = True
 
     def _init(self):
         if self.async_mq:
